@@ -97,12 +97,11 @@ class Taiyi:
         return {"月": day.getLunarMonth(), "日":day.getLunarDay()}
     
     def dzdistance(self):
-        return [twentyfourjieqir(self.year).get("冬至") - datetime.datetime.strptime(str(self.year)+"-"+str(self.month)+"-"+str(self.day), '%Y-%m-%d').date()][0].days
-   
+        return [find_jq_date(self.year, self.month, self.day, self.hour, "冬至") -  datetime.datetime(self.year,self.month, self.day, self.hour, 0,0)][0].days                                                                                  
     
     def xzdistance(self):
-        return [twentyfourjieqir(self.year).get("夏至") - datetime.datetime.strptime(str(self.year)+"-"+str(self.month)+"-"+str(self.day), '%Y-%m-%d').date()][0].days
-        
+        return [find_jq_date(self.year, self.month, self.day, self.hour, "夏至") -  datetime.datetime(self.year,self.month, self.day, self.hour, 0,0)][0].days           
+            
     def kook(self):
         dz = self.dzdistance()
         xz = self.xzdistance()
